@@ -1,6 +1,6 @@
-"""TODO: Initialization package."""
+"""Initialization package."""
 from .api import Mullpy
 from .banner import banner
 
 __all__ = ['Mullpy', 'banner']
-__version__ = '0.1.5'
+__version__ = '0.3.0'
