@@ -1,12 +1,14 @@
-"""TODO: CLI."""
+"""Command Line Interface module."""
 import click
-import argparse
 from .api import Mullpy
 from .banner import banner
 
 
-def main():
-    """TODO: CLI main."""
+@click.command()
+@click.option('--dns', '-l', is_flag=True)
+@click.option('--port', '-p', type=int, default=0)
+def main(dns, port=0):
+    """CLI for Mullvad API."""
     mullpy = Mullpy()
 
     if mullpy.exit_ip:
@@ -49,9 +51,25 @@ def main():
         click.secho('True', fg='red', bold=True)
     else:
         click.secho('False', fg='green', bold=True)
-    print()
-    exit(0)
+
+    # Dns Leak results from bash.ws
+    if dns:
+        print('DNS Leak: ', end='\t')
+        if mullpy.is_leaking():
+            click.secho('True', fg='red', bold=True)
+        else:
+            click.secho('False', fg='green', bold=True)
+
+    # Check if port is open
+    if port:
+        print(f'Port {port}: ', end='\t')
+        if mullpy.check_port(port):
+            click.secho('Open', fg='green', bold=True)
+        else:
+            click.secho('Closed', fg='red', bold=True)
+        print()
+        exit(0)
 
 
 if __name__ == '__main__':
-    main()
+    main(None)
